@@ -20,7 +20,7 @@ our @EXPORT_OK = qw(
     second      range
 );
 
-our $VERSION = '0.23';
+our $VERSION = '0.25';
 
 use constant ARG_PLACE_HOLDER => {};
 
@@ -79,14 +79,6 @@ sub _is_nonsense_range {
         return 1;
     }
 
-    #TODO Refactor this...;
-    if ($start > $end &&
-        $step == 0 &&
-        $start < 0 &&
-        $end < 0) {
-        return 0;
-    }
-
     if ($start > $end &&
         $step >= 0 ) {
         return 1;
@@ -466,22 +458,29 @@ sub partial {
     }
 }
 
+
+#Once again, forgive me for I have sinned...
 sub _fill_holders {
-    my ($oldArgs, $newArgs) = @_;
+    my ($old_args, $new_args) = @_;
 
-    if (none(sub { eql($_[0], __) }, $oldArgs)) {
-        return [@$oldArgs, @$newArgs];
-    }
+    my $filled_args  = [];
+    my $old_args_len = len($old_args);
 
-    return reduces(sub {
-        my ($args, $arg) = @_;
+    for (my $idx = 0; $idx < $old_args_len; $idx++) {
+        my $arg = shift @{ $old_args };
 
-        if (!eql($arg, __)) {
-            return [spread($args), $arg]
+        if (eql($arg, __)) {
+            push @{ $filled_args }, (shift @{ $new_args });
+        } else {
+            push @{ $filled_args }, $arg;
         }
 
-        return [spread($args), shift @{ $newArgs }]
-    }, [], [spread($oldArgs), spread($newArgs)]);
+        if ($old_args_len == ($idx + 1)) {
+            push @{ $filled_args }, @{ $new_args };
+        }
+    }
+
+    return $filled_args;
 }
 
 sub subarray {
@@ -513,8 +512,8 @@ sub chain {
 }
 
 sub eql {
-    my $arg1 = shift // __;
-    my $arg2 = shift // __;
+    my $arg1 = shift;
+    my $arg2 = shift;
 
     if (ref $arg1 ne ref $arg2) {
         return 0;
@@ -640,14 +639,12 @@ If end is not specified, it's set to start with start then set to 0.
     # [1, 1, 1]
 
 
+    #Ranges that "dont make sense" will return empty arrays
+
     range(-1, -4, 0);
 
     # [-1, -1, -1]
 
-
-    #Ranges that "dont make sense" will return empty arrays
-
-
     range(100, 1, 0)
 
     # []
